dojo.provide("com.ibm.pb.control.DNDController");
dojo.require("com.ibm.pb.logging.Loggable");
dojo.require("com.ibm.pb.layout.LayoutParser");

dojo.declare("com.ibm.pb.control.DNDController", com.ibm.pb.logging.Loggable, {	
	
	DND_TYPE: "lm",
	SHELF_TYPE: "sm",
	CONTROL_CLASS: "component-control",
	CONTAINER_CLASS: "component-container",
	DND_HANDLE_CLASS: "component-control-draghandle",
	DND_ORIENTATION: {vertical: "vertical", horizontal: "horizontal", freeform: "freeform"},
	
	dndSources: {}, 		// all of the dnd sources created on the page
	isDndLoaded: false, 	// has the controller been initialized?
	ghostHeight: 0, 		// store ghost height to use cross-source
	ghostAddedHeight: false,// Boolean used to determine if height was added to control node, used on resized widgets
	currentNode: null, 		// current node being dragged
	
	layoutParser: com.ibm.pb.layout.LayoutParser,
	
	nm: null, //navigation model
	
	constructor: function(){
		var lgr = this.LOGGER, mname = "constructor";
		lgr.entering(mname, arguments);
		
		com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService")
			.subscribeEvent("com.ibm.mashups.builder.changePageMode", this, this.onPageModeChanged);
		this.sourceDefinitions = ibmCfg.themeConfig.dndSourceDefinitions;
		
		// get layout model
		this.nm = com.ibm.mashups.enabler.navigation.Factory.getNavigationModel();
				
		lgr.exiting(mname, arguments);
	},
	init: function() {
		var lgr = this.LOGGER, mname = "init";
		lgr.entering(mname, arguments);			
		this.getContainers().forEach(
			function(container){									
				dojo.query("."+this.CONTROL_CLASS, container).forEach(
					function(control){	
						dojo.addClass(control, "dojoDndItem");
						dojo.attr(control, "dndType", this.DND_TYPE);
					}
				, this);		
				
				this.dndSources[container.id] = null;		
				var cls = null;
				var object = null;
				var orientation = null;

				dojo.forEach(this.sourceDefinitions, function(sourceDef){
					if(dojo.hasClass(container, sourceDef.id)){
						object = sourceDef.object;
						orientation = sourceDef.orientation;
						
						cls = dojo.getObject(object);
						if(!cls) {
							dojo["require"](object);
							cls = dojo.getObject(object);
							if(!cls) {
								console.error("%o not found", object);
								return;
							}
						}
					}
				}, this);

				if (cls) {
					this.dndSources[this.layoutParser.extractID(container)] = new cls(container, {
						horizontal: (this.DND_ORIENTATION.horizontal == orientation),
						creator: dojo.getObject(object+".creator"), 
						accept: [this.DND_TYPE, this.SHELF_TYPE],
						withHandles: dojo.getObject(object+".withHandles") ? true : false,
						singular: true,
						skipForm: true
					});
				}
			}
		, this);	
			
		this.isDndLoaded = true;	
		
		lgr.exiting(mname, arguments);
	},
	getContainers: function() {
		if(!this.containers) {
			this.containers = dojo.query("."+this.CONTAINER_CLASS);
		}
		return this.containers;
	},
	destroySources: function(){
		for(var name in this.dndSources){
			if(name) this.dndSources[name].destroy();
		}
		this.dndSources = {};
	},
	reset: function() {
		this.destroySources();
		this.isDndLoaded = false;
		delete this.containers;
	},
	onPageModeChanged: function(iEvent){
		var lgr = this.LOGGER, mname = "onPageModeChanged";
		lgr.entering(mname, arguments);
		if(iEvent == "edit") {
			if(!this.isDndLoaded){
				this.init();
			}else{
				for (var i in this.dndSources) {
                    if(!!this.dndSources[i]) this.dndSources[i].isSource = true;
                }
			}
		} else {
			if (this.isDndLoaded) {
				for (var i in this.dndSources) {
                    if(!!this.dndSources[i]) this.dndSources[i].isSource = false;
                }
			}
		}
		
		lgr.exiting(mname, arguments);
	}
});

(function(){
	var controller = null;
	com.ibm.pb.control.DNDController.getController = function() {
		if(!controller) {
			controller = new com.ibm.pb.control.DNDController();
		}
		return controller;
	};
})();