dojo.provide( "com.ibm.pb.data.InstalledPortletStore" );

dojo.require("dojo.data.util.simpleFetch");
dojo.require( "com.ibm.data.AtomFeedStore" );
dojo.require( "com.ibm.data.CatalogMixin" );

dojo.declare( "com.ibm.pb.data.InstalledPortletStore",
			[com.ibm.data.AtomFeedStore,com.ibm.data.CatalogMixin],
			{
				// itemClass: String the class used to represent items of this store
				itemClass: "com.ibm.pb.data.InstalledPortletItem",
				_loadFinished: false,
				_items: [],
				noIcons: true,
				idPrefix: "",
				
				constructor: function( /*Map*/ args ) {
				},
				
				/********************************/
				/**                            **/
				/**                            **/
				/**  catalog extension point   **/
				/**                            **/
				/**                            **/
				/********************************/
				
				mapItem: function(/*DatstoreItem*/item){
					var map = {};
					var id = this.getEPResolvedValue(item, "id", "");
					map.id = id.indexOf(this.idPrefix) == 0 ? id.substring(this.idPrefix.length) : id;
					map.label = this.getEPResolvedValue(item, "title", "untitled");
					map.description = this.getEPResolvedValue(item, "summary", "");
					return map;
				},
			
				_fetchItems: function(/*Object*/ keywordArgs, /*Function*/ findCallback, /*Function*/ errorCallback){
					// summary: see dojo.data.util.simpleFetch
					//The _fetchItems() method should ignore any keywordArgs parameters for start, count, onBegin, onItem, onComplete, onError, sort, and scope, and only needs to handle queryOptions and query
					var me = this;
					var filter = function(requestArgs, arrayOfItems){ 
						
						var items = [];
						if(requestArgs.query){
							var keywordStrings = requestArgs.query.keywords;
							var ignoreCase = requestArgs.queryOptions ? requestArgs.queryOptions.ignoreCase : false; 
							
							// loop through the keywordStrings and push anything that isn't an empty string onto the keywords array
							var keywords = [];
							for(var i = 0; i < keywordStrings.length; i++){
								if(keywordStrings[i].length <= 0) { continue; }
								// make the keyword all lower case if we are doing a case insensitive search
								var keyword = (ignoreCase)?keywordStrings[i].toLowerCase():keywordStrings[i];
								keywords.push(keyword);
							}

							// loop through all the items in the store looking for matches
							for(var i = 0; i < arrayOfItems.length; ++i){
								var match = true;
								if(arrayOfItems[i] === null){
									match = false; 
								} else {
									// loop through each keyword and make sure the store item contains all of them to be a match
									for(var j = 0; j < keywords.length; j++){
										var title = me.getValue(arrayOfItems[i],"title","");
										if(ignoreCase) { title = title.toLowerCase(); } // make the title all lower case if we are doing a case insensitive search
										var summary = me.getValue(arrayOfItems[i],"summary","");
										if(ignoreCase) { summary = summary.toLowerCase(); } // make the summary all lower case if we are doing a case insensitive search
										// if the title AND summary both don't contain the keyword, the match is false
										if(title.indexOf(keywords[j]) == -1 && summary.indexOf(keywords[j]) == -1){
											match = false;
											break;
										}
									}
								}
								if(match) { items.push(arrayOfItems[i]); }
							}
							findCallback(items, requestArgs);
						} else {
							findCallback(arrayOfItems, requestArgs);
						}
					};

					if(this._loadFinished){ 
						filter(keywordArgs, this._items);
					} else {  // the items in the store must be fetched and stored for the first and last time
						var args = arguments;  // create a reference to arguments
						var savedOnComplete = arguments[0].onComplete;  // save a reference to arguments' onComplete function
						// create a new onComplete function to pass to the inherited fetch function
						args[0].onComplete = function(items){  	args[0].onComplete = savedOnComplete; // restore the onComplete function for _fetchItems
																me._loadFinished = true; 
																me._items = items;	// store the items in the store
																filter(keywordArgs,items);
															};
						// retrieve all the store items using the inherited fetch function
						com.ibm.data.AtomFeedStore.prototype.fetch.apply(this, args);
					}
				}
});
dojo.extend(com.ibm.pb.data.InstalledPortletStore,dojo.data.util.simpleFetch);

dojo.declare( "com.ibm.pb.data.InstalledPortletItem",
			com.ibm.data.AtomEntryItem, 
			{
			}
);
