/* Copyright IBM Corp. 2012  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.runtime.skin.StyleFilter");
//dojo..require("com.ibm.mashups.enabler.layout.LayoutNode");
dojo.require("com.ibm.mashups.enabler.runtime.skin.StyleFilterChain");
dojo.require("com.ibm.mashups.enabler.runtime.skin.FilterControl");

/**
 * This filter interface allows for checking and filtering style changes on a runtime skin node
 *
 * @ibm-api
 * @ibm-module CoreModel
 * @since 2.4
 */
dojo.declare( "com.ibm.mashups.enabler.runtime.skin.StyleFilter", null, {
	/**
	 * Allows the filter to agree on style changes for the skin it is operating on. <br><br>
	 * <b>Note: a filter should not make state changes on this method</b>
	 * @param {com.ibm.mashups.enabler.layout.LayoutNode} layoutNode LayoutNode which contains this skin. Will not be <code>null</code>.
	 * @param {JSON} oldStyle the old style attributes of the skin and will never be <code>null</code>.  For example:<br>
     * <code>&#123; <br>
     * &nbsp;&nbsp;position: "absolute",<br>
     * &nbsp;&nbsp;left: "18px", <br>
     * &nbsp;&nbsp;width: "400px", <br>
     * &nbsp;&nbsp;height: "325px", <br>
     * &nbsp;&nbsp;z-index "51", <br>
     * &#125; </code><br>
	 * @param {JSON} newStyle updated style attributes for the skin. Will not be <code>null</code>.  For example:<br>
     * <code>&#123; <br>
     * &nbsp;&nbsp;position: "absolute",<br>
     * &nbsp;&nbsp;left: "18px", <br>
     * &nbsp;&nbsp;width: "400px", <br>
     * &nbsp;&nbsp;height: "325px", <br>
     * &nbsp;&nbsp;z-index "51", <br>
     * &#125; </code><br>
     * @param {FilterControl} control object used for a filter to disagree.
     * @param {com.ibm.mashups.enabler.runtime.skin.StyleFilterChain} filterChain filter chain used to call the next filter in the chain
     * @type void
	 */
	onChangingStyle: function(layoutNode, oldStyle, newStyle, control, filterChain) {
	},
	
	/**
     * allows the filter to take action on the new style attributes of the skin. 
     * @param {com.ibm.mashups.enabler.layout.LayoutNode} layoutNode LayoutNode which contains this skin. Will not be <code>null</code>.
     * @param {JSON} oldStyle the old style attributes of the skin and will never be <code>null</code>.  For example:<br>
     * <code>&#123; <br>
     * &nbsp;&nbsp;position: "absolute",<br>
     * &nbsp;&nbsp;left: "18px", <br>
     * &nbsp;&nbsp;width: "400px", <br>
     * &nbsp;&nbsp;height: "325px", <br>
     * &nbsp;&nbsp;z-index "51", <br>
     * &#125; </code><br>
     * @param {JSON} newStyle updated style attributes for the skin. Will not be <code>null</code>.  For example:<br>
     * <code>&#123; <br>
     * &nbsp;&nbsp;position: "absolute",<br>
     * &nbsp;&nbsp;left: "18px", <br>
     * &nbsp;&nbsp;width: "400px", <br>
     * &nbsp;&nbsp;height: "325px", <br>
     * &nbsp;&nbsp;z-index "51", <br>
     * &#125; </code><br>
     * @param {com.ibm.mashups.enabler.runtime.skin.StyleFilterChain} filterChain filter chain used to call the next filter in the chain
     * @type void
     */
    onChangeStyle: function(layoutNode, oldStyle, newStyle, filterChain) {
    },
	
	/**
     * allows the filter to be notified if the layout control has been modified
     * @param {com.ibm.mashups.enabler.layout.LayoutNode} layoutControl layout control
     * @type void
     * @private
     */
    onChangeLayoutControl: function(layoutControl) {
    }
});
